function [IdMateria,SemestreMateria,RecursoMateria,CreditosMateria,NumeroRequerimientoMateria] = Materia(workbookFile,sheetName,startRow,endRowMateria)
%IMPORTFILE9 Import data from a spreadsheet
%   [IdMateria1,NombreMateria1,SemestreMateria1,RecursoMateria1,CreditosMateria1,NumeroRequerimientoMateria]
%   = IMPORTFILE9(FILE) reads data from the first worksheet in the
%   Microsoft Excel spreadsheet file named FILE and returns the data as
%   column vectors.
%
%   [IdMateria1,NombreMateria1,SemestreMateria1,RecursoMateria1,CreditosMateria1,NumeroRequerimientoMateria]
%   = IMPORTFILE9(FILE,SHEET) reads from the specified worksheet.
%
%   [IdMateria1,NombreMateria1,SemestreMateria1,RecursoMateria1,CreditosMateria1,NumeroRequerimientoMateria]
%   = IMPORTFILE9(FILE,SHEET,STARTROW,ENDROW) reads from the specified
%   worksheet for the specified row interval(s). Specify STARTROW and
%   ENDROW as a pair of scalars or vectors of matching size for
%   dis-contiguous row intervals. To read to the end of the file specify an
%   ENDROW of inf.
%
%	Non-numeric cells are replaced with: NaN
%
% Example:
%   [IdMateria1,NombreMateria1,SemestreMateria1,RecursoMateria1,CreditosMateria1,NumeroRequerimientoMateria] = importfile9('Libro1.xlsx','Hoja1',1,1048576);
%
%   See also XLSREAD.

% Auto-generated by MATLAB on 2019/06/22 10:16:59

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 3
    startRow = 1;
    endRowMateria = 1048576;
end

%% Import the data
[~, ~, raw] = xlsread(workbookFile, sheetName, sprintf('A%d:F%d',startRow(1),endRowMateria(1)));
for block=2:length(startRow)
    [~, ~, tmpRawBlock] = xlsread(workbookFile, sheetName, sprintf('A%d:F%d',startRow(block),endRowMateria(block)));
    raw = [raw;tmpRawBlock]; %#ok<AGROW>
end
raw(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),raw)) = {''};
cellVectors = raw(:,2);
raw = raw(:,[1,3,4,5,6]);

%% Replace non-numeric cells with NaN
R = cellfun(@(x) ~isnumeric(x) && ~islogical(x),raw); % Find non-numeric cells
raw(R) = {NaN}; % Replace non-numeric cells

%% Create output variable
I = cellfun(@(x) ischar(x), raw);
raw(I) = {NaN};
data = reshape([raw{:}],size(raw));

%% Allocate imported array to column variable names
IdMateria = data(:,1);
SemestreMateria = data(:,2);
RecursoMateria = data(:,3);
CreditosMateria = data(:,4);
NumeroRequerimientoMateria = data(:,5);

