function [IdRequerimiento,MateriaRequerimiento,EstudianteRequerimiento] = Requerimiento(workbookFile,sheetName,startRow,endRowRequerimiento)
%IMPORTFILE9 Import data from a spreadsheet
%   [IdRequerimiento1,MateriaRequerimiento,EstudianteRequerimiento1] =
%   IMPORTFILE9(FILE) reads data from the first worksheet in the Microsoft
%   Excel spreadsheet file named FILE and returns the data as column
%   vectors.
%
%   [IdRequerimiento1,MateriaRequerimiento,EstudianteRequerimiento1] =
%   IMPORTFILE9(FILE,SHEET) reads from the specified worksheet.
%
%   [IdRequerimiento1,MateriaRequerimiento,EstudianteRequerimiento1] =
%   IMPORTFILE9(FILE,SHEET,STARTROW,ENDROW) reads from the specified
%   worksheet for the specified row interval(s). Specify STARTROW and
%   ENDROW as a pair of scalars or vectors of matching size for
%   dis-contiguous row intervals. To read to the end of the file specify an
%   ENDROW of inf.
%
%	Non-numeric cells are replaced with: NaN
%
% Example:
%   [IdRequerimiento1,MateriaRequerimiento,EstudianteRequerimiento1] = importfile9('Libro1.xlsx','Hoja1',1,1048576);
%
%   See also XLSREAD.

% Auto-generated by MATLAB on 2019/06/22 10:21:36

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 3
    startRow = 1;
    endRowRequerimiento = 1048576;
end

%% Import the data
[~, ~, raw] = xlsread(workbookFile, sheetName, sprintf('G%d:I%d',startRow(1),endRowRequerimiento(1)));
for block=2:length(startRow)
    [~, ~, tmpRawBlock] = xlsread(workbookFile, sheetName, sprintf('G%d:I%d',startRow(block),endRowRequerimiento(block)));
    raw = [raw;tmpRawBlock]; %#ok<AGROW>
end
raw(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),raw)) = {''};

%% Replace non-numeric cells with NaN
R = cellfun(@(x) ~isnumeric(x) && ~islogical(x),raw); % Find non-numeric cells
raw(R) = {NaN}; % Replace non-numeric cells

%% Create output variable
I = cellfun(@(x) ischar(x), raw);
raw(I) = {NaN};
data = reshape([raw{:}],size(raw));

%% Allocate imported array to column variable names
IdRequerimiento = data(:,1);
MateriaRequerimiento = data(:,2);
EstudianteRequerimiento = data(:,3);

